@@ -1,21 +1,34 @@
 import logging
 from http import HTTPStatus
 from logging import Logger
-from typing import Union
+import os
+from typing import List, Union
 
 import click
 import uvicorn
-from fastapi import FastAPI, Security
+from fastapi import FastAPI, Security, Request
 from fastapi.middleware.cors import CORSMiddleware
 from fastapi.routing import APIRouter
 from injector import inject
 from pydantic import AnyHttpUrl
 
-from isar.apis.models.models import StartMissionResponse
+from opencensus.ext.azure.trace_exporter import AzureExporter
+from opencensus.trace.samplers import ProbabilitySampler
+from opencensus.trace.tracer import Tracer
+from opencensus.trace.span import SpanKind
+from opencensus.trace.attributes_helper import COMMON_ATTRIBUTES
+
+from isar.apis.models.models import ControlMissionResponse, StartMissionResponse
 from isar.apis.schedule.scheduling_controller import SchedulingController
 from isar.apis.security.authentication import Authenticator
+from isar.config.configuration_error import ConfigurationError
+from isar.config.keyvault.keyvault_error import KeyvaultError
+from isar.config.keyvault.keyvault_service import Keyvault
 from isar.config.settings import settings
 
+HTTP_URL = COMMON_ATTRIBUTES["HTTP_URL"]
+HTTP_STATUS_CODE = COMMON_ATTRIBUTES["HTTP_STATUS_CODE"]
+
 
 class API:
     @inject
@@ -23,14 +36,16 @@ class API:
         self,
         authenticator: Authenticator,
         scheduling_controller: SchedulingController,
-        host: str = settings.API_HOST,
+        keyvault_client: Keyvault,
         port: int = settings.API_PORT,
+        azure_ai_logging_enabled: bool = settings.LOG_HANDLER_APPLICATION_INSIGHTS_ENABLED,
     ) -> None:
-
         self.authenticator: Authenticator = authenticator
         self.scheduling_controller: SchedulingController = scheduling_controller
-        self.host: str = host
+        self.keyvault_client: Keyvault = keyvault_client
+        self.host: str = "0.0.0.0"  # Locking uvicorn to use 0.0.0.0
         self.port: int = port
+        self.azure_ai_logging_enabled: bool = azure_ai_logging_enabled
 
         self.logger: Logger = logging.getLogger("api")
 
@@ -66,7 +81,7 @@ class API:
         )
 
         if self.authenticator.should_authenticate():
-            backend_cors_origins: list[Union[str, AnyHttpUrl]] = [
+            backend_cors_origins: List[Union[str, AnyHttpUrl]] = [
                 f"http://{self.host}:{self.port}"
             ]
 
@@ -78,20 +93,25 @@ class API:
                 allow_headers=["*"],
             )
 
+        if self.azure_ai_logging_enabled:
+            self._add_request_logging_middleware(app)
+
         app.include_router(router=self._create_scheduler_router())
 
+        app.include_router(router=self._create_info_router())
+
         return app
 
     def _create_scheduler_router(self) -> APIRouter:
-
         router: APIRouter = APIRouter(tags=["Scheduler"])
 
         authentication_dependency: Security = Security(self.authenticator.get_scheme())
 
         router.add_api_route(
-            "/schedule/start-mission/{id}",
-            self.scheduling_controller.start_mission_by_id,
+            path="/schedule/start-mission/{id}",
+            endpoint=self.scheduling_controller.start_mission_by_id,
             methods=["POST"],
+            deprecated=True,
             dependencies=[authentication_dependency],
             summary="Start a mission with id='id' from the current mission planner",
             responses={
@@ -105,17 +125,14 @@ class API:
                 HTTPStatus.CONFLICT.value: {
                     "description": "Conflict - Invalid command in the current state",
                 },
-                HTTPStatus.REQUEST_TIMEOUT.value: {
-                    "description": "Timeout - Could not contact state machine",
-                },
                 HTTPStatus.INTERNAL_SERVER_ERROR.value: {
                     "description": "Internal Server Error - Current state of state machine unknown",
                 },
             },
         )
         router.add_api_route(
-            "/schedule/start-mission",
-            self.scheduling_controller.start_mission,
+            path="/schedule/start-mission",
+            endpoint=self.scheduling_controller.start_mission,
             methods=["POST"],
             dependencies=[authentication_dependency],
             summary="Start the mission provided in JSON format",
@@ -130,47 +147,40 @@ class API:
                 HTTPStatus.CONFLICT.value: {
                     "description": "Conflict - Invalid command in the current state",
                 },
-                HTTPStatus.REQUEST_TIMEOUT.value: {
-                    "description": "Timeout - Could not contact state machine",
-                },
                 HTTPStatus.INTERNAL_SERVER_ERROR.value: {
                     "description": "Internal Server Error - Current state of state machine unknown",
                 },
             },
         )
         router.add_api_route(
-            "/schedule/stop-mission",
-            self.scheduling_controller.stop_mission,
+            path="/schedule/stop-mission",
+            endpoint=self.scheduling_controller.stop_mission,
             methods=["POST"],
             dependencies=[authentication_dependency],
             summary="Stop the current mission",
             responses={
                 HTTPStatus.OK.value: {
                     "description": "Mission succesfully stopped",
+                    "model": ControlMissionResponse,
                 },
                 HTTPStatus.CONFLICT.value: {
                     "description": "Conflict - Invalid command in the current state",
                 },
-                HTTPStatus.REQUEST_TIMEOUT.value: {
-                    "description": "Timeout - Could not contact state machine",
-                },
                 HTTPStatus.INTERNAL_SERVER_ERROR.value: {
                     "description": "Internal Server Error - Current state of state machine unknown",
                 },
             },
         )
         router.add_api_route(
-            "/schedule/pause-mission",
-            self.scheduling_controller.pause_mission,
+            path="/schedule/pause-mission",
+            endpoint=self.scheduling_controller.pause_mission,
             methods=["POST"],
             dependencies=[authentication_dependency],
             summary="Pause the current mission",
             responses={
                 HTTPStatus.OK.value: {
                     "description": "Mission succesfully paused",
-                },
-                HTTPStatus.REQUEST_TIMEOUT.value: {
-                    "description": "Timeout - Could not contact state machine",
+                    "model": ControlMissionResponse,
                 },
                 HTTPStatus.CONFLICT.value: {
                     "description": "Conflict - Invalid command in the current state",
@@ -181,17 +191,15 @@ class API:
             },
         )
         router.add_api_route(
-            "/schedule/resume-mission",
-            self.scheduling_controller.resume_mission,
+            path="/schedule/resume-mission",
+            endpoint=self.scheduling_controller.resume_mission,
             methods=["POST"],
             dependencies=[authentication_dependency],
             summary="Resume the currently paused mission - if any",
             responses={
                 HTTPStatus.OK.value: {
                     "description": "Mission succesfully resumed",
-                },
-                HTTPStatus.REQUEST_TIMEOUT.value: {
-                    "description": "Timeout - Could not contact state machine",
+                    "model": ControlMissionResponse,
                 },
                 HTTPStatus.CONFLICT.value: {
                     "description": "Conflict - Invalid command in the current state",
@@ -202,8 +210,8 @@ class API:
             },
         )
         router.add_api_route(
-            "/schedule/drive-to",
-            self.scheduling_controller.drive_to,
+            path="/schedule/drive-to",
+            endpoint=self.scheduling_controller.drive_to,
             methods=["POST"],
             dependencies=[authentication_dependency],
             summary="Drive to the provided pose",
@@ -211,9 +219,6 @@ class API:
                 HTTPStatus.OK.value: {
                     "description": "Drive to succesfully started",
                 },
-                HTTPStatus.REQUEST_TIMEOUT.value: {
-                    "description": "Timeout - Could not contact state machine",
-                },
                 HTTPStatus.CONFLICT.value: {
                     "description": "Conflict - Invalid command in the current state",
                 },
@@ -225,6 +230,21 @@ class API:
 
         return router
 
+    def _create_info_router(self) -> APIRouter:
+        router: APIRouter = APIRouter(tags=["Info"])
+
+        authentication_dependency: Security = Security(self.authenticator.get_scheme())
+
+        router.add_api_route(
+            path="/info/robot-settings",
+            endpoint=self.scheduling_controller.get_info,
+            methods=["GET"],
+            dependencies=[authentication_dependency],
+            summary="Information about the robot-settings",
+        )
+
+        return router
+
     def _log_startup_message(self) -> None:
         address_format = "%s://%s:%d/docs"
         message = f"Uvicorn running on {address_format} (Press CTRL+C to quit)"
@@ -234,7 +254,6 @@ class API:
             + click.style(address_format, bold=True)
             + " (Press CTRL+C to quit)"
         )
-
         self.logger.info(
             message,
             protocol,
@@ -242,3 +261,36 @@ class API:
             self.port,
             extra={"color_message": color_message},
         )
+
+    def _add_request_logging_middleware(self, app: FastAPI) -> None:
+        connection_string: str
+        try:
+            connection_string = self.keyvault_client.get_secret(
+                "application-insights-connection-string"
+            ).value
+        except KeyvaultError:
+            message: str = (
+                "Missing connection string for Application Insights in key vault. "
+            )
+            self.logger.critical(message)
+            raise ConfigurationError(message)
+
+        @app.middleware("http")
+        async def middlewareOpencensus(request: Request, call_next):
+            tracer = Tracer(
+                exporter=AzureExporter(connection_string=connection_string),
+                sampler=ProbabilitySampler(1.0),
+            )
+            with tracer.span("main") as span:
+                span.span_kind = SpanKind.SERVER
+
+                response = await call_next(request)
+
+                tracer.add_attribute_to_current_span(
+                    attribute_key=HTTP_STATUS_CODE, attribute_value=response.status_code
+                )
+                tracer.add_attribute_to_current_span(
+                    attribute_key=HTTP_URL, attribute_value=str(request.url)
+                )
+
+            return response
