@@ -2,6 +2,7 @@ import importlib.resources as pkg_resources
 import os
 from typing import List
 
+from dotenv import load_dotenv
 from pydantic import BaseSettings, Field, validator
 
 from isar.config import predefined_missions
@@ -101,7 +102,7 @@ class Settings(BaseSettings):
     AZURE_TENANT_ID: str = Field(default="3aa4a235-b6e2-48d5-9195-7fcf05b459b0")
 
     # Client ID for the API client
-    APP_CLIENT_ID: str = Field(default="68cca82d-84e7-495c-96b4-4c32509f2a46")
+    APP_CLIENT_ID: str = Field(default="fd384acd-5c1b-4c44-a1ac-d41d720ed0fe")
 
     # Client ID for the OpenAPI client
     OPENAPI_CLIENT_ID: str = Field(default="5f412c20-8c36-4c69-898f-d2b5051f5fb6")
@@ -299,6 +300,7 @@ class Settings(BaseSettings):
         case_sensitive = True
 
 
+load_dotenv()
 settings = Settings()
 
 
