@@ -23,7 +23,9 @@ from tests.mocks.token import MockToken
         ),
     ],
 )
-def test_get_position(stid_service, mocker, tag, expected_position, mock_return):
+def test_get_position(
+    stid_service, mocker, tag, expected_position, mock_return
+) -> None:
     mocker.patch.object(DefaultAzureCredential, "get_token", return_value=MockToken())
     mocker.patch.object(RequestHandler, "get", return_value=mock_return)
     position: Position = stid_service.tag_position(tag=tag)
